<?php
if (!defined('ABSPATH')) exit; // Exit if accessed directly

CSF::createWidget('csf_footer_two_widget', array(
    'title'       => esc_html__('Footer Two - Conbix', 'conbix-toolkit'),
    'classname'   => 'csf-footer-two-widget',
    'description' =>  esc_html__('This Widget for Footer Style 02 - Conbix', 'conbix-toolkit'),
    'fields'      => array(
        // A Subheading
        array(
            'type'    => 'subheading',
            'content' => esc_html__('Widget One', 'conbix-toolkit'),
        ),

        array(
            'id'           => 'widget_one_logo',
            'type'         => 'media',
            'title'        => esc_html__('Hamburger Logo', 'conbix-toolkit'),
            'library'      => 'image',
            'url'          => false,
            'button_title' => esc_html__('Upload', 'conbix-toolkit'),
            'default'   => array(
                'url' => get_theme_file_uri('assets/img/logo-4.png'),
                'thumbnail' => get_theme_file_uri('assets/img/logo-4.png'),
            ),
        ),

        array(
            'id'      => 'comapny_content',
            'type'    => 'textarea',
            'title'   => esc_html__('Content', 'conbix-toolkit'),
            'default' => esc_html__('Lorem Ipsum is Dummy Content', 'conbix-toolkit'),
        ),

        array(
            'id'        => 'socials_group',
            'type'      => 'group',
            'title'     => esc_html__('Social Media Lists', 'conbix-toolkit'),
            'fields'    => array(
                array(
                    'id'      => 'social-icon',
                    'type'    => 'icon',
                    'title'   => esc_html__('Icon', 'conbix-toolkit'),
                    'default' => 'fa fa-facebook'
                ),
                array(
                    'id'    => 'social-url',
                    'type'  => 'text',
                    'title' => esc_html__('URL', 'conbix-toolkit'),
                ),
            ),
            'default'   => array(
                array(
                    'social-icon'  => 'fab fa-facebook-f',
                    'social-url'   => 'facebook.com',
                ),
                array(
                    'social-icon'  => 'fab fa-twitter',
                    'social-url'   => 'twitter.com',
                ),
            ),
        ),

        // A Subheading
        array(
            'type'    => 'subheading',
            'content' => esc_html__('Widget Two', 'conbix-toolkit'),
        ),

        array(
            'id'      => 'widget_two_title',
            'type'    => 'text',
            'title'   => esc_html__('Widget Two Title', 'conbix-toolkit'),
            'default' => esc_html__('Head Office', 'conbix-toolkit'),
        ),

        array(
            'id'        => 'widget_two_office',
            'type'      => 'group',
            'title'     => esc_html__('Office Info', 'conbix-toolkit'),
            'fields'    => array(

                array(
                    'id'     => 'office-title',
                    'type'   => 'text',
                    'title'  => esc_html__('Title', 'conbix-toolkit'),
                ),
                array(
                    'id'      => 'office-icon',
                    'type'    => 'icon',
                    'title'   => esc_html__('Icon', 'conbix-toolkit'),
                    'default' => 'fa fa-heart'
                ),
                array(
                    'id'     => 'office-text',
                    'type'   => 'textarea',
                    'title'  => esc_html__('Content', 'conbix-toolkit'),
                ),
                array(
                    'id'     => 'office-url',
                    'type'   => 'text',
                    'title'  => esc_html__('URL', 'conbix-toolkit'),
                ),
            ),
            'default'   => array(
                array(
                    'office-icon'  => 'fal fa-map-marker-alt',
                    'office-text'  => esc_html__('8502 Preston Rd. Inglewood, Maine 98380', 'conbix-toolkit'),
                    'office-url'   => esc_attr__('http://google.com/maps', 'conbix-toolkit'),
                    'office-title' => 'Branch Office',
                ),
            ),
        ),

        // A Subheading
        array(
            'type'    => 'subheading',
            'content' => esc_html__('Widget Three', 'conbix-toolkit'),
        ),

        array(
            'id'      => 'widget_three_title',
            'type'    => 'text',
            'title'   => esc_html__('Widget Three Title', 'conbix-toolkit'),
            'default' => esc_html__('Recent Post', 'conbix-toolkit'),
        ),
    )
));

if (!function_exists('csf_footer_two_widget')) {
    function csf_footer_two_widget($args, $instance)
    {

        echo $args['before_widget'];

        $widget_logo = $instance['widget_one_logo'];
        $comapny_content = $instance['comapny_content'];
        $socials = $instance['socials_group'];
        $widget_two_title = $instance['widget_two_title'];
        $widget_two_office = $instance['widget_two_office'];
        $widget_three_title = $instance['widget_three_title'];

        $post_type = array(
            'post_type'           => 'post',
            'posts_per_page'      => 2,
            'ignore_sticky_posts' => true,
        );

        $resent_post = new WP_Query($post_type);
?>


        <div class="container">
            <div class="row">
                <div class="col-xl-4 col-lg-4 col-md-6 lg-mb-30">
                    <div class="footer__two-widget">
                        <div class="footer__two-widget-about">
                            <?php if (!empty($widget_logo['url'])) : ?>
                                <a href="<?php echo get_site_url(); ?>"> <img src="<?php echo esc_url($widget_logo['url']); ?>" alt="logo"> </a>
                            <?php endif ?>
                            <p><?php echo esc_html($comapny_content); ?></p>
                            <?php if (is_array($socials) || is_object($socials)) : ?>
                                <div class="footer__two-widget-about-social">
                                    <ul>
                                        <?php foreach ($socials as $social) { ?>
                                            <li><a href="<?php echo esc_url($social['social-url']); ?>"><i class="<?php echo esc_attr($social['social-icon']); ?>"></i></a></li>
                                        <?php } ?>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="col-xl-4 col-lg-4 col-md-6 md-mb-30">
                    <div class="footer__two-widget footer-border">
                        <h4><?php echo esc_html($widget_two_title); ?></h4>
                        <div class="footer__two-widget-location">
                            <?php if (is_array($widget_two_office) || is_object($widget_two_office)) : ?>
                                <?php foreach ($widget_two_office as $widget_two_off) { ?>
                                    <?php if (!empty($widget_two_off['office-title'])) : ?><h6><?php echo esc_html($widget_two_off['office-title']); ?></h6><?php endif; ?>
                                    <div class="footer__two-widget-location-item">
                                        <div class="footer__two-widget-location-item-icon">
                                            <i class="<?php echo esc_attr($widget_two_off['office-icon']); ?>"></i>
                                        </div>
                                        <div class="footer__two-widget-location-item-info">
                                            <a href="<?php echo esc_url($widget_two_off['office-url']); ?>"><?php echo esc_html($widget_two_off['office-text']); ?></a>
                                        </div>
                                    </div>
                                <?php } ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="col-xl-4 col-lg-4 col-md-6">
                    <div class="footer__two-widget footer-border">
                        <h4><?php echo esc_html($widget_three_title); ?></h4>
                        <?php if ($resent_post->have_posts()) : ?>
                            <?php while ($resent_post->have_posts()) : $resent_post->the_post(); ?>
                                <!-- loop -->
                                <div class="post__item">
                                    <div class="post__item-image">
                                        <a href="<?php echo esc_url(get_permalink()); ?>"><img src="<?php the_post_thumbnail_url('thumbnail') ?>" alt="<?php echo get_post_meta(get_post_thumbnail_id(), '_wp_attachment_image_alt', true); ?>"></a>
                                    </div>
                                    <div class="post__item-title">
                                        <span><i class="far fa-calendar-alt"></i><?php the_time(get_option('date_format')) ?></span>
                                        <h6><a href="<?php echo esc_url(get_permalink()); ?>"><?php the_title(); ?></a></h6>
                                    </div>
                                </div>
                            <?php endwhile;
                            wp_reset_postdata(); ?>
                        <?php else :  ?>
                            <p><?php echo esc_html('Sorry, no posts matched your criteria.', 'conbix-toolkit'); ?></p>
                        <?php endif; ?>
                        <!-- loop -->
                    </div>
                </div>
            </div>
        </div>


<?php
        echo $args['after_widget'];
    }
}
